@@ -3,7 +3,7 @@
 
 # demo.py --- Demonstration program and cheap test suite for pythondialog
 #
-# Copyright (C) 2002-2010, 2013, 2014, 2015  Florent Rougon
+# Copyright (C) 2002-2019  Florent Rougon
 # Copyright (C) 2000  Robb Shecter, Sultanbek Tezadov
 #
 # This program is in the public domain.
@@ -77,10 +77,10 @@ import dialog
 from dialog import DialogBackendVersion
 
 progname = os.path.basename(sys.argv[0])
-progversion = "0.11"
+progversion = "0.12"
 version_blurb = """Demonstration program and cheap test suite for pythondialog.
 
-Copyright (C) 2002-2010, 2013, 2014, 2015  Florent Rougon
+Copyright (C) 2002-2010, 2013-2016  Florent Rougon
 Copyright (C) 2000  Robb Shecter, Sultanbek Tezadov
 
 This is free software; see the source for copying conditions.  There is NO
@@ -959,7 +959,7 @@ when leaving the help dialog. {complement}""".format(complement=complement)
              9, 20, 54, 0, READ_ONLY),
             ("Read-only field...", 10, 1, "... that doesn't go into the "
              "output list", 10, 20, 0, 0, 0x0),
-            ("\/3r`/ 53kri7 (0d3", 11, 1, "", 11, 20, 15, 20, HIDDEN) ]
+            (r"\/3r`/ 53kri7 (0d3", 11, 1, "", 11, 20, 15, 20, HIDDEN) ]
 
         code, fields = d.mixedform(
             "Please fill in some personal information:", elements, width=77)
@@ -1402,7 +1402,21 @@ You should now select a node with the space bar."""
         if os.path.isfile(filepath):
             code, text = d.editbox(filepath, 20, 60,
                                    title="A Cheap Text Editor")
+            d.scrollbox(text, title="Resulting text")
+        else:
+            d.msgbox("Skipping the first part of the 'editbox' demo, "
+                     "as '{0}' can't be found.".format(filepath),
+                     title="'msgbox' demo")
 
+        l = ["In the previous dialog, the initial contents was",
+             "explicitly written to a file. With Dialog.editbox_str(),",
+             "you can provide it as a string and pythondialog will",
+             "automatically create and delete a temporary file for you",
+             "holding this text for dialog.\n"] + \
+             [ "This is line {0} of a boring sample text.".format(i+1)
+               for i in range(100) ]
+        code, text = d.editbox_str('\n'.join(l), 0, 0,
+                                   title="A Cheap Text Editor")
         d.scrollbox(text, title="Resulting text")
 
     def inputmenu_demo(self):
